<?php
/**
 *	Index.php
 *
 *	@author		{$author}
 *	@package	{$project_id}
 *	@version 	$Id: app.action.default.php,v 1.12 2006/03/23 13:16:37 fujimoto Exp $
 */

/**
 *	indexեμ
 *
 *	@author		{$author}
 *	@access		public
 *	@package	{$project_id}
 */
class {$project_id}_Form_Index extends Ethna_ActionForm
{
	/**
	 *	@access	private
	 *	@var	array	ե
	 */
	var	$form = array(
		/*
		 *	TODO: Υ󤬻Ѥե򵭽ҤƤ
		 *
		 *	(typeƤǤϾάǽ)
		 *
		 *	'sample' => array(
		 *		'name'			=> 'ץ',		// ɽ̾
		 *		'required'      => true,			// ɬܥץ(true/false)
		 *		'min'           => null,			// Ǿ
		 *		'max'           => null,			// 
		 *		'regexp'        => null,			// ʸ(ɽ)
		 *		'custom'        => null,			// ᥽åɤˤå
		 *		'filter'        => null,			// Ѵե륿ץ
		 *		'form_type'     => FORM_TYPE_TEXT,	// ե෿
		 *		'type'          => VAR_TYPE_INT,	// ͷ
		 *	),
		 */
	);
}

/**
 *	indexμ
 *
 *	@author		{$author}
 *	@access		public
 *	@package	{$project_id}
 */
class {$project_id}_Action_Index extends Ethna_ActionClass
{
	/**
	 *	index
	 *
	 *	@access	public
	 *	@return	string		Forward(ｪλʤnull)
	 */
	function prepare()
	{
		return null;
	}

	/**
	 *	indexμ
	 *
	 *	@access	public
	 *	@return	string	̾
	 */
	function perform()
	{
		return 'index';
	}
}
?>
